@@ -1,15 +1,12 @@
 import typing
 
 import jsonlog
-
+import jsonlog_cli.types
 
 log = jsonlog.getLogger(__name__)
 
-RecordKey = str
-RecordValue = typing.Union[None, str, int, float, bool, typing.Sequence, typing.Mapping]
 
-
-class RecordDict(dict, typing.Mapping[str, RecordValue]):
+class RecordDict(dict, typing.Mapping[str, jsonlog_cli.types.Value]):
     """A mapping that allows access to values as if they were attributes."""
 
     def __getattr__(self, item) -> typing.Any:
@@ -27,7 +24,7 @@ class Record(typing.Mapping[str, typing.Any]):
     def ordered_keys(self) -> typing.Iterable[str]:
         return self.data.keys()
 
-    def extract(self, key: typing.Optional[str]) -> RecordValue:
+    def extract(self, key: typing.Optional[str]) -> jsonlog_cli.types.Value:
         if key is None:
             return None
 
@@ -35,7 +32,7 @@ class Record(typing.Mapping[str, typing.Any]):
             return self.data[key]
         return self._extract(key)
 
-    def _extract(self, key: str) -> RecordValue:
+    def _extract(self, key: str) -> jsonlog_cli.types.Value:
         result = self.data
 
         for k in key.split("."):
